Client

Struct Client 

pub struct Client { /* private fields */ }
Async, cheap-to-clone client for the Zammad REST API.

Use Client::builder to construct one. All resource handles (Client::tickets, Client::users, …) borrow &self so cloning is rarely needed, but cloning is cheap (one Arc::clone) when you do want to move the client into a long-lived task.

Implementations

Source

impl Client

pub fn builder() -> ClientBuilder

Start a new ClientBuilder.

pub fn new(url: impl Into<String>, auth: Auth) -> Result<Self>

Shorthand for Client::builder().url(...).auth(...).build().

pub fn base_url(&self) -> &str

Base URL the client was configured with, without a trailing slash.

pub fn tickets(&self) -> TicketsApi<'_>

Handle for ticket endpoints.

pub fn articles(&self) -> ArticlesApi<'_>

Handle for ticket-article (reply / note / email) endpoints.

pub fn users(&self) -> UsersApi<'_>

Handle for user endpoints.

pub fn organizations(&self) -> OrganizationsApi<'_>

Handle for organization endpoints.

pub fn groups(&self) -> GroupsApi<'_>

Handle for group (queue) endpoints.

pub fn tags(&self) -> TagsApi<'_>

Handle for tag endpoints.

pub fn states(&self) -> StatesApi<'_>

Handle for ticket-state endpoints.

pub fn priorities(&self) -> PrioritiesApi<'_>

Handle for ticket-priority endpoints.

pub fn knowledge_base(&self) -> KnowledgeBaseApi<'_>

Handle for Knowledge Base (FAQ) endpoints.